**Example 1: 修改目标组名称**

修改目标组名称

Input: 

```
tccli clb ModifyTargetGroupAttribute --cli-unfold-argument  \
    --TargetGroupId lbtg-815iz538 \
    --TargetGroupName xxxxholic
```

Output: 
```
{
    "Response": {
        "RequestId": "73d80971-512f-400e-9c73-c0c135c04871"
    }
}
```

